==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI.h <==
// class javax.swing.plaf.basic.BasicTabbedPaneUI$ScrollingPanel$ScrollingPanelUI

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class d7f8ed72eea34302 javax_swing_plaf_PanelUI
// @dep_class 2d7c79ec306a699e javax_swing_plaf_basic_BasicPanelUI
// @dep_class c2cb40268526e7d1 javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicPanelUI

#include "javax/swing/plaf/basic/BasicPanelUI.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI_H_
#define _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI_H_

// Forward structure declarations
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__241$object;
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$sub_refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$object	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$vmethods	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$vtable	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$vtype	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$method$_init$be799916424eb86b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$object *);
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$method$_init$36f9aed800560e7e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__241$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$method$paint$772d1272d1c3f8bb(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$object *, struct _jc_java_awt_Graphics$object *, struct _jc_javax_swing_JComponent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$method_info$paint$772d1272d1c3f8bb;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$vmethods {
	void	(*paint$772d1272d1c3f8bb)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$object *, struct _jc_java_awt_Graphics$object *, struct _jc_javax_swing_JComponent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_PanelUI$vmethods	javax_swing_plaf_PanelUI;
	_jc_javax_swing_plaf_basic_BasicPanelUI$vmethods	javax_swing_plaf_basic_BasicPanelUI;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$vmethods	javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$refs {
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$sub_refs	javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI;
    _jc_javax_swing_plaf_basic_BasicPanelUI$sub_refs	javax_swing_plaf_basic_BasicPanelUI;
    _jc_javax_swing_plaf_PanelUI$sub_refs	javax_swing_plaf_PanelUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_PanelUI$sub_nonrefs	javax_swing_plaf_PanelUI;
    _jc_javax_swing_plaf_basic_BasicPanelUI$sub_nonrefs	javax_swing_plaf_basic_BasicPanelUI;
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$sub_nonrefs	javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$object {
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$vtype _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI.h <==
// class javax.swing.plaf.basic.BasicTabbedPaneUI$ScrollingPanel$ScrollingPanelUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class d7f8ed72eea34302 javax_swing_plaf_PanelUI
// @dep_class 2d7c79ec306a699e javax_swing_plaf_basic_BasicPanelUI
// @dep_class c2cb40268526e7d1 javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicPanelUI

#include "javax/swing/plaf/basic/BasicPanelUI.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI_H_
#define _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI_H_

// Forward structure declarations
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__241$object;
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$sub_refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$object	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$vmethods	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$vtable	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$vtype	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$method$_init$be799916424eb86b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$method$_init$36f9aed800560e7e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$method$paint$772d1272d1c3f8bb(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$object *, struct _jc_java_awt_Graphics$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$method_info$paint$772d1272d1c3f8bb;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$vmethods {
	void	(*paint$772d1272d1c3f8bb)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$object *, struct _jc_java_awt_Graphics$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_PanelUI$vmethods	javax_swing_plaf_PanelUI;
	_jc_javax_swing_plaf_basic_BasicPanelUI$vmethods	javax_swing_plaf_basic_BasicPanelUI;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$vmethods	javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$refs {
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$sub_refs	javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI;
    _jc_javax_swing_plaf_basic_BasicPanelUI$sub_refs	javax_swing_plaf_basic_BasicPanelUI;
    _jc_javax_swing_plaf_PanelUI$sub_refs	javax_swing_plaf_PanelUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_PanelUI$sub_nonrefs	javax_swing_plaf_PanelUI;
    _jc_javax_swing_plaf_basic_BasicPanelUI$sub_nonrefs	javax_swing_plaf_basic_BasicPanelUI;
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$sub_nonrefs	javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$object {
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$vtype _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel__24ScrollingPanelUI_H_ */
